@@ -2,9 +2,9 @@
 # If any private function or specific import is defined in a module, remove '*' and list the functions.
 from .utils import idx_closest, sign_change_detect
 from .utils_geo import *
-from .ncload import var_load, get_lon_lat
+from .ncload import *
 from .compute import *
-from .plot import lon_lat_plot
+from .plot import lon_lat_plot, zonal_plot
 from .basins import *
 
 try:
